==> typestyle-0.14.0.tgz: package/lib/internal/formatting.js <==
"use strict";
var FreeStyle = require("free-style");
function ensurePercent(value) {
    return typeof value === 'number'
        ? value
        : parseFloat(ensureString(value)) * .01;
}
exports.ensurePercent = ensurePercent;
function formatPercent(value) {
    return (value * 100) + '%';
}
exports.formatPercent = formatPercent;
/**
 * Before we send styles to freeStyle we should convert any CSSType<T> to string
 * Call this whenever something might be a CSSType.
 */
function ensureString(x) {
    return typeof x.type === 'string'
        ? x.toString()
        : x;
}
exports.ensureString = ensureString;
/**
 * We need to do the following to *our* objects before passing to freestyle:
 * - Convert any CSSType to their string value
 * - For any `$nest` directive move up to FreeStyle style nesting
 * - For any `$unique` directive map to FreeStyle Unique
 */
function ensureStringObj(object) {
    /** The final result we will return */
    var result = {};
    for (var key in object) {
        /** Grab the value upfront */
        var val = object[key];
        /** TypeStyle configuration options */
        if (key === '$unique') {
            result[FreeStyle.IS_UNIQUE] = val;
        }
        else if (key === '$nest') {
            var nested = val;
            for (var selector in nested) {
                var subproperties = nested[selector];
                result[selector] = ensureStringObj(subproperties);
            }
        }
        else {
            result[key] = ensureString(val);
        }
    }
    return result;
}
exports.ensureStringObj = ensureStringObj;
function parseCSSFunction(stringValue) {
    var matches = /[\s]*([a-z-]+)[\s]*\([\s]*([^\)]+)[\s]*\)[\s]*/ig.exec(stringValue);
    if (!matches || !matches.length) {
        return undefined;
    }
    return [matches[1]].concat(matches[2].split(','));
}
exports.parseCSSFunction = parseCSSFunction;

==> typestyle-0.18.3.tgz: package/lib/internal/formatting.js <==
"use strict";
var FreeStyle = require("free-style");
function ensurePercent(value) {
    return typeof value === 'number'
        ? value
        : parseFloat(ensureString(value)) * .01;
}
exports.ensurePercent = ensurePercent;
function formatPercent(value) {
    return (value * 100) + '%';
}
exports.formatPercent = formatPercent;
/**
 * Before we send styles to freeStyle we should convert any CSSType<T> to string
 * Call this whenever something might be a CSSType.
 */
function ensureString(x) {
    return typeof x.type === 'string'
        ? x.toString()
        : x;
}
exports.ensureString = ensureString;
/**
 * We need to do the following to *our* objects before passing to freestyle:
 * - Convert any CSSType to their string value
 * - For any `$nest` directive move up to FreeStyle style nesting
 * - For any `$unique` directive map to FreeStyle Unique
 * - For any `$debugName` directive return the debug name
 */
function ensureStringObj(object) {
    /** The final result we will return */
    var result = {};
    var debugName = '';
    for (var key in object) {
        /** Grab the value upfront */
        var val = object[key];
        /** TypeStyle configuration options */
        if (key === '$unique') {
            result[FreeStyle.IS_UNIQUE] = val;
        }
        else if (key === '$nest') {
            var nested = val;
            for (var selector in nested) {
                var subproperties = nested[selector];
                result[selector] = ensureStringObj(subproperties).result;
            }
        }
        else if (key === '$debugName') {
            debugName = val;
        }
        else {
            result[key] = ensureString(val);
        }
    }
    return { result: result, debugName: debugName };
}
exports.ensureStringObj = ensureStringObj;
function parseCSSFunction(stringValue) {
    var matches = /[\s]*([a-z-]+)[\s]*\([\s]*([^\)]+)[\s]*\)[\s]*/ig.exec(stringValue);
    if (!matches || !matches.length) {
        return undefined;
    }
    return [matches[1]].concat(matches[2].split(','));
}
exports.parseCSSFunction = parseCSSFunction;
